==> u61-0.1.1.tar.gz: u61-0.1.1/script/package/couple.lua <==
------------------------------------------------------------------------------
--                                                                          --
-- U U    6   1            U U   FFF  O   O  TTT                            --
-- U U   6   11   b        U U   F   O O O O  T                             --
-- U U - 66   1   bb  y y  U U - FF  O O O O  T                             --
-- U U   6 6  1   b b  y   U U   F   O O O O  T                             --
--  U     6   1   bb   y    U    F    O   O   T                             --
--                                                                          --
-- U61 is another block based game                                          --
-- Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   --
--                                                                          --
-- This program is free software; you can redistribute it and/or            --
-- modify it under the terms of the GNU General Public License              --
-- as published by the Free Software Foundation; either version 2           --
-- of the License, or (at your option) any later version.                   --
--                                                                          --
-- This program is distributed in the hope that it will be useful,          --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of           --
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            --
-- GNU General Public License for more details.                             --
--                                                                          --
-- You should have received a copy of the GNU General Public License        --
-- along with this program; if not, write to the Free Software              --
-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA--
--                                                                          --
-- This project is also available on SourceForge  (http://sourceforge.net)  --
------------------------------------------------------------------------------

-- couple game, you have blocks with two squares of different colors, it's
-- possible to translate and rotate them, and one need to have 4 adjacent
-- squares (at least) of the same color to make them disappear 


-- shape definition ----------------------------------------------------------

function user_block_shape(num)
    vertical_colored_bar(2,num)
end


-- actions -------------------------------------------------------------------

function user_block_rotate_left()
    block_geometric_rotate_left()    
end

function user_block_rotate_right()
    block_geometric_rotate_right()    
end

function user_block_move_left()
    block_translate_x(-1)
end

function user_block_move_right()
    block_translate_x(1)
end

function user_block_move_down()
    block_translate_y(1)
end


-- pattern match -------------------------------------------------------------

function user_map_match_pattern()

end

function user_block_land()
    block_split()
end

==> u61-0.1.2.tar.gz: u61-0.1.2/script/package/couple.lua <==
------------------------------------------------------------------------------
--                                                                          --
-- U U    6   1            U U   FFF  O   O  TTT                            --
-- U U   6   11   b        U U   F   O O O O  T                             --
-- U U - 66   1   bb  y y  U U - FF  O O O O  T                             --
-- U U   6 6  1   b b  y   U U   F   O O O O  T                             --
--  U     6   1   bb   y    U    F    O   O   T                             --
--                                                                          --
-- U61 is another block based game                                          --
-- Copyright (C) 2000 Christian Mauduit (ufoot@ufoot.org / www.ufoot.org)   --
--                                                                          --
-- This program is free software; you can redistribute it and/or            --
-- modify it under the terms of the GNU General Public License              --
-- as published by the Free Software Foundation; either version 2           --
-- of the License, or (at your option) any later version.                   --
--                                                                          --
-- This program is distributed in the hope that it will be useful,          --
-- but WITHOUT ANY WARRANTY; without even the implied warranty of           --
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            --
-- GNU General Public License for more details.                             --
--                                                                          --
-- You should have received a copy of the GNU General Public License        --
-- along with this program; if not, write to the Free Software              --
-- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA--
--                                                                          --
-- This project is also available on SourceForge  (http://sourceforge.net)  --
------------------------------------------------------------------------------

-- couple game, you have blocks with two squares of different colors, it's
-- possible to translate and rotate them, and one need to have 4 adjacent
-- squares (at least) of the same color to make them disappear 


-- shape definition ----------------------------------------------------------

function user_block_shape(num)
    vertical_colored_bar(2,num)
end


-- actions -------------------------------------------------------------------

function user_block_rotate_left()
    block_geometric_rotate_left()    
end

function user_block_rotate_right()
    block_geometric_rotate_right()    
end

function user_block_move_left()
    block_translate_x(-1)
end

function user_block_move_right()
    block_translate_x(1)
end

function user_block_move_down()
    block_translate_y(1)
end


-- pattern match -------------------------------------------------------------

function user_map_match_pattern()
    return 0
end

function user_block_land()
    block_split()
end

-- other functions -----------------------------------------------------------

function user_map_time_callback()
    u61_map_add_score(1)
end
